/*
Widget Name:
- Custom Material Card
Description:
- Cards contain content and actions about a single subject.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-materialCard.dart';

Usage:
-Creating the object for the card

    onclickCardBtn(int nIndex, String sText) {print(nIndex);print(sText);}
    MaterialCardData Obj1 = new MaterialCardData(
        title: "Colosseum",
        subtitle: "The Colosseum in Rome was built in the first century by order of the Emperor Vespasian",
        containerHeight: 400.0,
        containerWidth: 350.0,
        icon: Icon(Icons.room,
        color: Colors.grey,
        size: 30,),
        containerDecoration: BoxDecoration(
          boxShadow: [
            BoxShadow(
                color: Colors.white,
                blurRadius: 10,
                offset: Offset.zero)
          ],
          borderRadius: BorderRadius.circular(20),
          color: Colors.white,
        ),
        textStyle1: TextStyle(
          color: Colors.black,
          fontSize: 20,
          fontWeight: FontWeight.bold,
        ),
        textStyle2: TextStyle(
          color: Colors.black,
          fontSize: 16.0,
        ),
        btnText: "View",
        btnColor: Colors.black,
        imgType: "Network",
        imgPath: "https://cdn.britannica.com/75/75775-050-1FC4B34B/Colosseum-Rome.jpg");


    -Widget call for the widget
        body: customMaterialCardWidget(Obj1, onclickCardBtn),

    ****Note:
    - imgType decides weather the image source is network image or asset image.

    Author:
        Satyabrat Padhy
*/

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/consts.dart' as constants;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget customMaterialCardWidget(
    MaterialCardData data, void Function(int, String) callback) {
  ImageProvider image;
  if (data.imgType != null && data.imgType == constants.Asset ||
      data.imgType == constants.asset) {
    image = (data.imgPath == null)
        ? AssetImage(constants.cardImagePath)
        : AssetImage(data.imgPath);
  } else if (data.imgType != null && data.imgType == constants.Network ||
      data.imgType == constants.network) {
    image = (data.imgPath == null)
        ? NetworkImage(constants.networkCardImagePath)
        : NetworkImage(data.imgPath);
  } else {
    image = NetworkImage(constants.networkCardImagePath);
  }
  return Padding(
    padding: EdgeInsets.all(
        (data.padding1 != null) ? data.padding1 : constants.heightThirty),
    child: Container(
      decoration: (data.containerDecoration != null)
          ? data.containerDecoration
          : BoxDecoration(
              boxShadow: [
                BoxShadow(
                    color: mediumGreyThemeData().backgroundColor,
                    blurRadius: constants.heightTen,
                    offset: Offset.zero)
              ],
              borderRadius: BorderRadius.circular(constants.heightFive),
              color: mediumGreyThemeData().primaryColor,
            ),
      height: (data.containerHeight != null)
          ? data.containerHeight
          : constants.heightFourHundred,
      width: (data.containerWidth != null)
          ? data.containerWidth
          : constants.heightThreeHundred,
      child: SingleChildScrollView(
        child: Container(
          child: Column(
            children: <Widget>[
              Card(
                child: Semantics(
                  label:
                      (data.title != null) ? data.title : constants.cardTitle,
                  child: Container(
                    height: (data.imgHeight != null)
                        ? data.imgWidth
                        : constants.heightOneEighty,
                    decoration: BoxDecoration(
                      image: DecorationImage(
                          image: (image != null)
                              ? image
                              : NetworkImage(constants.networkCardImagePath),
                          fit: BoxFit.fill),
                    ),
                  ),
                ),
              ),
              ListTile(
                leading: (data.icon != null)
                    ? data.icon
                    : Icon(
                        Icons.home,
                        size: constants.heightFifty,
                        color: mediumGreyThemeData().highlightColor,
                      ),
                title: Text(
                  (data.title != null) ? data.title : constants.cardTitle,
                  style: (data.textStyle1 != null)
                      ? data.textStyle1
                      : TextStyle(
                          color: mediumGreyThemeData().primaryColorDark,
                          fontSize: constants.fontLarger,
                          fontWeight: constants.fontBold,
                        ),
                  overflow: TextOverflow.ellipsis,
                ),
                contentPadding: EdgeInsets.all((data.padding2 != null)
                    ? data.padding2
                    : constants.heightTwenty),
                subtitle: Text(
                  (data.subtitle != null)
                      ? data.subtitle
                      : constants.cardSubtitle,
                  style: (data.textStyle2 != null)
                      ? data.textStyle2
                      : TextStyle(
                          color: mediumGreyThemeData().primaryColorDark,
                          fontSize: constants.fontMedium,
                          fontWeight: constants.fontBold,
                        ),
                  overflow: TextOverflow.ellipsis,
                  maxLines: constants.maxLines,
                  softWrap: true,
                ),
              ),
              ButtonBar(
                children: <Widget>[
                  RaisedButton(
                    color: (data.btnColor != null)
                        ? data.btnColor
                        : mediumGreyThemeData()
                            .tabBarTheme
                            .unselectedLabelColor,
                    child: Text(
                      data.btnText != null
                          ? data.btnText
                          : constants.cardBtnText,
                      style: (data.textStyle3 != null)
                          ? data.textStyle3
                          : TextStyle(fontSize: constants.fontMedium),
                    ),
                    onPressed: () => {
                      callback(1,
                          data.title != null ? data.title : constants.cardTitle)
                    },
                  ),
                ],
              ),
            ],
          ),
        ),
      ),
    ),
  );
}
