/*
Description:
Creates a Sliver AppBar for the page. It has a title and various icon buttons which can be used for routing.
Different combinations of the bool values of floating, pinned and snap make different types of scrolls for the appbar

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-sliverAppBar.dart';

Usage:
-Creating the object for the sliver appbar

    SliverAppBarParameters params = new SliverAppBarParameters(
        backgroundColor: Colors.black,
        expandedHeight: 150,
        elevation: 5,
        titleSpacing: 20.0,
        centerTitle: false,
        stretch: true,
        snap: false,
        pinned: true,
        floating: false,
        title:Text('Sliver AppBar'));

    List<Widget> sliverProducts = [
      IconButton(
        icon:  Icon(Icons.search),
        onPressed: () {},
      ),
      IconButton(
        icon:  Icon(Icons.help),
        onPressed: () {},
      ),
      IconButton(
        icon:  Icon(Icons.verified_user),
        onPressed: () {},
      ),
    ];

    -Object call for the widget
    body: CustomScrollView(
          slivers: <Widget>[
            customSliverAppBar(sliverProducts, params),
            SliverList(
              delegate: SliverChildListDelegate(
                <Widget>[
                  Container(height: 1200.0),
                ],
              ),
            ),
          ],
        ),

    Author:
    Karan Arora
*/

import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/consts.dart' as cons;

Widget customSliverAppBar(
    List<Widget> sliverProducts, SliverAppBarParameters params) {
  if (params == null) {
    return SliverAppBar(
      automaticallyImplyLeading: cons.automaticallyImplyLeading,
      expandedHeight: cons.expandedHeight,
      flexibleSpace: cons.flexibleSpaceBar,
      forceElevated: cons.forceElevated,
      brightness: cons.brightness,
      iconTheme: mediumGreyThemeData().iconTheme,
      actionsIconTheme: mediumGreyThemeData().iconTheme,
      textTheme: mediumGreyThemeData().textTheme,
      primary: cons.primary,
      floating: cons.floating,
      pinned: cons.pinned,
      snap: cons.snap,
      stretch: cons.stretch,
      leading: null,
      elevation: cons.elevationFive,
      centerTitle: cons.centerTitle,
      backgroundColor: mediumGreyThemeData().scaffoldBackgroundColor,
      titleSpacing: cons.tileSpacingOne,
      title: cons.title,
      actions: cons.action,
      bottom: null,
      stretchTriggerOffset: cons.stretchTriggerOffset,
      shape: null,
    );
  } else {
    if (params.bottom != null) {
      return SliverAppBar(
        automaticallyImplyLeading: (params.automaticallyImplyLeading != null)
            ? params.automaticallyImplyLeading
            : cons.automaticallyImplyLeading,
        iconTheme: (params.iconTheme != null)
            ? params.iconTheme
            : mediumGreyThemeData().iconTheme,
        leading: (params.leading != null) ? params.leading : null,
        elevation:
            (params.elevation != null) ? params.elevation : cons.elevationFive,
        centerTitle: (params.centerTitle != null)
            ? params.centerTitle
            : cons.centerTitle,
        backgroundColor: (params.backgroundColor != null)
            ? params.backgroundColor
            : mediumGreyThemeData().scaffoldBackgroundColor,
        titleSpacing: (params.titleSpacing != null)
            ? params.titleSpacing
            : cons.tileSpacingOne,
        title: (params.title != null) ? params.title : cons.title,
        actions: sliverProducts,
        stretchTriggerOffset: (params.stretchTriggerOffset != null)
            ? params.stretchTriggerOffset
            : cons.stretchTriggerOffset,
        floating: (params.floating != null) ? params.floating : cons.floating,
        pinned: (params.pinned != null) ? params.pinned : cons.pinned,
        snap: (params.snap != null) ? params.snap : cons.snap,
        stretch: (params.stretch != null) ? params.stretch : cons.stretch,
        expandedHeight: (params.expandedHeight != null)
            ? params.expandedHeight
            : cons.expandedHeight,
        flexibleSpace: (params.flexibleSpace != null)
            ? params.flexibleSpace
            : cons.flexibleSpaceBar,
        primary: (params.primary != null) ? params.primary : cons.primary,
        actionsIconTheme: (params.actionsIconTheme != null)
            ? params.actionsIconTheme
            : mediumGreyThemeData().iconTheme,
        brightness:
            (params.brightness != null) ? params.brightness : cons.brightness,
        bottom: params.bottom,
        textTheme: (params.textTheme != null)
            ? params.textTheme
            : mediumGreyThemeData().textTheme,
        forceElevated: (params.forceElevated != null)
            ? params.forceElevated
            : cons.forceElevated,
        shape: (params.shape != null) ? params.shape : null,
      );
    } else {
      return SliverAppBar(
        automaticallyImplyLeading: (params.automaticallyImplyLeading != null)
            ? params.automaticallyImplyLeading
            : cons.automaticallyImplyLeading,
        expandedHeight: (params.expandedHeight != null)
            ? params.expandedHeight
            : cons.expandedHeight,
        flexibleSpace: (params.flexibleSpace != null)
            ? params.flexibleSpace
            : cons.flexibleSpaceBar,
        forceElevated: (params.forceElevated != null)
            ? params.forceElevated
            : cons.forceElevated,
        brightness:
            (params.brightness != null) ? params.brightness : cons.brightness,
        iconTheme: (params.iconTheme != null)
            ? params.iconTheme
            : mediumGreyThemeData().iconTheme,
        actionsIconTheme: (params.actionsIconTheme != null)
            ? params.actionsIconTheme
            : mediumGreyThemeData().iconTheme,
        textTheme: (params.textTheme != null)
            ? params.textTheme
            : mediumGreyThemeData().textTheme,
        primary: (params.primary != null) ? params.primary : cons.primary,
        floating: (params.floating != null) ? params.floating : cons.floating,
        pinned: (params.pinned != null) ? params.pinned : cons.pinned,
        snap: (params.snap != null) ? params.snap : cons.snap,
        stretch: (params.stretch != null) ? params.stretch : cons.stretch,
        leading: (params.leading != null) ? params.leading : null,
        elevation:
            (params.elevation != null) ? params.elevation : cons.elevationFive,
        centerTitle: (params.centerTitle != null)
            ? params.centerTitle
            : cons.centerTitle,
        backgroundColor: (params.backgroundColor != null)
            ? params.backgroundColor
            : mediumGreyThemeData().scaffoldBackgroundColor,
        titleSpacing: (params.titleSpacing != null)
            ? params.titleSpacing
            : cons.tileSpacingOne,
        title: (params.title != null) ? params.title : cons.title,
        actions: sliverProducts,
        shape: (params.shape != null) ? params.shape : null,
        stretchTriggerOffset: (params.stretchTriggerOffset != null)
            ? params.stretchTriggerOffset
            : cons.stretchTriggerOffset,
        bottom: null,
      );
    }
  }
}
